==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/nl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Gedeeld met je",
    "Shared with others" : "Gedeeld met anderen",
    "Shared by link" : "Gedeeld via een link",
    "Nothing shared with you yet" : "Nog niets met u gedeeld",
    "Files and folders others share with you will show up here" : "Bestanden en mappen die anderen met je delen, worden hier getoond",
    "Nothing shared yet" : "Nog niets gedeeld",
    "Files and folders you share will show up here" : "Bestanden en mappen die u deelt, worden hier getoond",
    "No shared links" : "Geen gedeelde links",
    "Files and folders you share by link will show up here" : "Bestanden en mappen die je via links deelt, worden hier getoond",
    "You can upload into this folder" : "Je kunt uploaden naar deze map",
    "No compatible server found at {remote}" : "Geen geschikte server gevonden op {remote}",
    "Invalid server URL" : "Ongeldig server URL",
    "Failed to add the public link to your Nextcloud" : "Kon de openbare link niet aan je Nextcloud toevoegen",
    "Share" : "Deel",
    "No expiration date set" : "Geen vervaldatum ingesteld",
    "Shared by" : "Gedeeld door",
    "Sharing" : "Delen",
    "File shares" : "File shares",
    "Downloaded via public link" : "Gedownload via een openbare link",
    "Downloaded by %1$s" : "Gedownload door %1$s",
    "Downloaded by {email}" : "Gedownload via {email}",
    "%1$s downloaded via public link" : "%1$s gedownload via openbare link",
    "{file} downloaded via public link" : "{file} gedownload via openbare link",
    "%1$s downloaded %2$s" : "%1$s downloadde %2$s",
    "{email} downloaded {file}" : "{email} downloadde {file}",
    "Shared with group %1$s" : "Deelde met groep %1$s",
    "Shared with group {group}" : "Deelde met groep {group}",
    "Removed share for group %1$s" : "Share van de groep %1$s verwijderd",
    "Removed share for group {group}" : "Share van de groep {group} verwijderd",
    "%2$s shared with group %1$s" : "%2$s deelde met groep %1$s",
    "{actor} shared with group {group}" : "{actor} deelde met groep {group}",
    "%2$s removed share for group %1$s" : "%2$s verwijderde share voor groep %1$s",
    "{actor} removed share for group {group}" : "{actor} verwijderde de share voor groep {group}",
    "You shared %1$s with group %2$s" : "Je deelde %1$s met groep %2$s",
    "You shared {file} with group {group}" : "Je deelde {file} met groep {group}",
    "You removed group %2$s from %1$s" : "Je verwijderde groep %2$s van %1$s",
    "You removed group {group} from {file}" : "Je verwijderde groep  {group} van {file}",
    "%3$s shared %1$s with group %2$s" : "%3$s deelde %1$s met groep %2$s",
    "{actor} shared {file} with group {group}" : "{actor} deelde {file} met groep {group}",
    "%3$s removed group %2$s from %1$s" : "%3$s verwijderde groep %2$s van %1$s",
    "{actor} removed group {group} from {file}" : "{actor} verwijderde groep {group} van {file}",
    "Shared as public link" : "Gedeeld als een openbare link",
    "Removed public link" : "Openbare link verwijderd",
    "%1$s shared as public link" : "%1$s deelde als een openbare link",
    "{actor} shared as public link" : "{actor} deelde als een openbare link",
    "%1$s removed public link" : "%1$s verwijderde openbare link",
    "{actor} removed public link" : "{actor} verwijderde openbare link",
    "You shared %1$s as public link" : "Je deelde %1$s als openbare link",
    "You shared {file} as public link" : "Je deelde {file} als openbare link",
    "You removed public link for %1$s" : "Je verwijderde de openbare link voor %1$s",
    "You removed public link for {file}" : "Je verwijderde de openbare link voor {file}",
    "%2$s shared %1$s as public link" : "%2$s deelde %1$s als een openbare link",
    "{actor} shared {file} as public link" : "{actor} deelde {file} als openbare link",
    "%2$s removed public link for %1$s" : "%2$s verwijderde openbare link voor %1$s",
    "{actor} removed public link for {file}" : "{actor} verwijderde openbare link voor {file}",
    "%1$s accepted the remote share" : "%1$s accepteerde externe share",
    "{user} accepted the remote share" : "{user} accepteerde externe share",
    "%1$s declined the remote share" : "%1$s weigerde externe share",
    "{user} declined the remote share" : "{user} weigerde externe share",
    "You received a new remote share %1$s from %2$s" : "Je ontving een nieuwe externe share voor %1$s van %2$s",
    "You received a new remote share {file} from {user}" : "Je ontving een nieuwe externe share voor {file} van {user}",
    "%2$s accepted the remote share of %1$s" : "%2$s accepteerde externe share van %1$s",
    "{user} accepted the remote share of {file}" : "{user} accepteerde externe share van {file}",
    "%2$s declined the remote share of %1$s" : "%2$s weigerde de externe share van %1$s",
    "{user} declined the remote share of {file}" : "{user} weigerde de externe share van {file}",
    "%2$s unshared %1$s from you" : "%2$s stopte met delen van %1$s met jou",
    "{user} unshared {file} from you" : "{user} stopte met delen van {file} met jou",
    "Shared with %1$s" : "Gedeeld met %1$s",
    "Shared with {user}" : "Gedeeld met {user}",
    "Removed share for %1$s" : "Verwijderde share voor %1$s",
    "Removed share for {user}" : "Verwijderde share voor {user}",
    "%2$s shared with %1$s" : "%2$s deelde met %1$s",
    "{actor} shared with {user}" : "{actor} deelde met {user}",
    "%2$s removed share for %1$s" : "%2$s verwijderde de share voor %1$s",
    "{actor} removed share for {user}" : "{actor} verwijderde de share voor {user}",
    "Shared by %1$s" : "Gedeeld door %1$s",
    "Shared by {actor}" : "Gedeeld door {actor}",
    "%1$s removed share" : "%1$s verwijderde de share",
    "{actor} removed share" : "{actor} verwijderde de share",
    "You shared %1$s with %2$s" : "Je deelde %1$s met %2$s",
    "You shared {file} with {user}" : "Je deelde {file} mey {user}",
    "You removed %2$s from %1$s" : "Je verwijderde %2$s van %1$s",
    "You removed {user} from {file}" : "Je verwijderde {user} van {file}",
    "%3$s shared %1$s with %2$s" : "%3$s deelde %1$s met %2$s",
    "{actor} removed {user} from {file}" : "{actor} verwijderde {user} van {file}",
    "%3$s removed %2$s from %1$s" : "%3$s verwijderde %2$s van %1$s",
    "%2$s shared %1$s with you" : "%2$s deelde %1$s met u",
    "{actor} shared {file} with you" : "{actor} deelde {file} met jou",
    "%2$s removed you from %1$s" : "%2$s verwijderde jou van %1$s",
    "{actor} removed you from {file}" : "{actor} verwijderde jou van {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Een bestand of map gedeeld via mail of publieke link werd <strong>gedownload</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Een bestand of map werd gedeeld vanaf <strong>een andere server</strong>",
    "A file or folder has been <strong>shared</strong>" : "Een bestand of map is <strong>gedeeld</strong>",
    "Wrong share ID, share doesn't exist" : "Onjuist deel-ID, de share bestaat niet",
    "could not delete share" : "Kon share niet verwijderen",
    "Could not delete share" : "Kon share niet verwijderen",
    "Please specify a file or folder path" : "Geef een bestand of pad van een map op",
    "Wrong path, file/folder doesn't exist" : "Onjuist pad, bestand/map bestaat niet",
    "Could not create share" : "Kon share niet aanmaken",
    "invalid permissions" : "Ongeldige rechten",
    "Please specify a valid user" : "Geef een geldige gebruiker op",
    "Group sharing is disabled by the administrator" : "Delen voor groepen is uitgeschakeld door de beheerder",
    "Please specify a valid group" : "Geef een geldige groep op",
    "Public link sharing is disabled by the administrator" : "Delen van openbare links is uitgeschakeld door de beheerder",
    "Public upload disabled by the administrator" : "Publieke upload uitgeschakeld door de systeembeheerder",
    "Public upload is only possible for publicly shared folders" : "Publieke upload is alleen mogelijk voor publiek gedeelde mappen",
    "Invalid date, date format must be YYYY-MM-DD" : "Ongeldige datum, datumnotatie moet in de vorm YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Delen van %s mislukte omdat de backend het delen van type %s niet ondersteunt",
    "Unknown share type" : "Onbekend type share",
    "Not a directory" : "Geen directory",
    "Could not lock path" : "Kon pad niet blokkeren",
    "Wrong or no update parameter given" : "Verkeerde of geen update parameter opgegeven",
    "Can't change permissions for public share links" : "Kan permissies voor openbare share links niet wijzigen",
    "Cannot increase permissions" : "Kan de rechten niet verruimen",
    "%s is publicly shared" : "%s is openbaar gedeeld",
    "Share API is disabled" : "Delen API is uitgeschakeld",
    "This share is password-protected" : "Deze share is met een wachtwoord beveiligd",
    "The password is wrong. Try again." : "Wachtwoord ongeldig. Probeer het nogmaals.",
    "Password" : "Wachtwoord",
    "No entries found in this folder" : "Niets gevonden in deze map",
    "Name" : "Naam",
    "Share time" : "Deel tijd",
    "Expiration date" : "Vervaldatm",
    "Sorry, this link doesn’t seem to work anymore." : "Sorry, deze link lijkt niet meer in gebruik te zijn.",
    "Reasons might be:" : "Redenen kunnen zijn:",
    "the item was removed" : "bestand was verwijderd",
    "the link expired" : "de link is verlopen",
    "sharing is disabled" : "delen is uitgeschakeld",
    "For more info, please ask the person who sent this link." : "Voor meer informatie, neem contact op met de persoon die u deze link heeft gestuurd.",
    "Add to your Nextcloud" : "Toevoegen aan je Nextcloud",
    "Download" : "Downloaden",
    "Download %s" : "Download %s",
    "Direct link" : "Directe link",
    "Upload files to %s" : "Upload bestanden naar %s",
    "Select or drop files" : "Selecteer of leg bestanden neer",
    "Uploading files…" : "Uploaden bestanden...",
    "Uploaded files:" : "Geüploade bestanden",
    "A public shared file or folder was <strong>downloaded</strong>" : "Een openbaar gedeeld bestand of map werd <strong>gedownloaded</strong>",
    "You received a new remote share %2$s from %1$s" : "Je ontving een nieuwe externe share %2$s van %1$s",
    "You received a new remote share from %s" : "Je ontving een nieuwe externe share van %s",
    "%1$s accepted remote share %2$s" : "%1$s accepteerde externe share %2$s",
    "%1$s declined remote share %2$s" : "%1$s weigerde externe share %2$s",
    "%1$s unshared %2$s from you" : "%1$s stopte met delen van %2$s met je",
    "Public shared folder %1$s was downloaded" : "Openbaar gedeelde map %1$s werd gedownloaded",
    "Public shared file %1$s was downloaded" : "Openbaar gedeeld bestand %1$s werd gedownloaded",
    "%2$s shared %1$s with %3$s" : "%2$s deelde %1$s met %3$s",
    "You removed the share of %2$s for %1$s" : "Je hebt de share van %1$s met %2$s verwijderd",
    "%2$s removed the share of %3$s for %1$s" : "%2$s heeft de share van %1$s met %3$s verwijderd",
    "%2$s shared %1$s with group %3$s" : "%2$s deelde %1$s met groep %3$s",
    "You removed the share of group %2$s for %1$s" : "Je hebt de share van %1$s met de groep %2$s verwijderd",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s heeft de share van %1$s met de groep %3$s verwijderd",
    "%2$s shared %1$s via link" : "%2$s deelde %1$s via link",
    "You shared %1$s via link" : "Je deelde %1$s via link",
    "You removed the public link for %1$s" : "Je hebt de openbare link voor %1$s verwijderd",
    "%2$s removed the public link for %1$s" : "%2$s heeft de openbare link voor %1$s verwijderd",
    "Your public link for %1$s expired" : "Je openbare link voor %1$s is verlopen",
    "The public link of %2$s for %1$s expired" : "De openbare link van %2$s voor %1$s is verlopen",
    "%2$s removed the share for %1$s" : "%2$s heeft de share van %1$s verwijderd",
    "Shared with %2$s" : "Gedeeld met %2$s",
    "Shared with %3$s by %2$s" : "Gedeeld met %3$s door %2$s",
    "Removed share for %2$s" : "Share van %2$s verwijderd",
    "%2$s removed share for %3$s" : "%2$s verwijderde de share van %3$s",
    "Shared with group %2$s" : "Gedeeld met groep %2$s",
    "Shared with group %3$s by %2$s" : "Gedeeld met groep %3$s door %2$s",
    "Removed share of group %2$s" : "Share van de groep %2$s verwijderd",
    "%2$s removed share of group %3$s" : "%2$s verwijderde share met groep %3$s",
    "Shared via link by %2$s" : "Gedeeld via link door %2$s",
    "Shared via public link" : "Gedeeld via een openbare link",
    "%2$s removed public link" : "%2$s verwijderede openbare link",
    "Public link expired" : "Openbare link is verlopen",
    "Public link of %2$s expired" : "Openbare link van %2$s is verlopen",
    "Shared by %2$s" : "Gedeeld door %2$s",
    "Shares" : "Gedeeld"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-11.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/nl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Gedeeld met je",
    "Shared with others" : "Gedeeld met anderen",
    "Shared by link" : "Gedeeld via een link",
    "Nothing shared with you yet" : "Nog niets met u gedeeld",
    "Files and folders others share with you will show up here" : "Bestanden en mappen die anderen met je delen, worden hier getoond",
    "Nothing shared yet" : "Nog niets gedeeld",
    "Files and folders you share will show up here" : "Bestanden en mappen die u deelt, worden hier getoond",
    "No shared links" : "Geen gedeelde links",
    "Files and folders you share by link will show up here" : "Bestanden en mappen die je via links deelt, worden hier getoond",
    "You can upload into this folder" : "Je kunt uploaden naar deze map",
    "No compatible server found at {remote}" : "Geen geschikte server gevonden op {remote}",
    "Invalid server URL" : "Ongeldig server URL",
    "Failed to add the public link to your Nextcloud" : "Kon de openbare link niet aan je Nextcloud toevoegen",
    "Share" : "Deel",
    "No expiration date set" : "Geen vervaldatum ingesteld",
    "Shared by" : "Gedeeld door",
    "Sharing" : "Delen",
    "File shares" : "File shares",
    "Downloaded via public link" : "Gedownload via een openbare link",
    "Downloaded by {email}" : "Gedownload via {email}",
    "{file} downloaded via public link" : "{file} gedownload via openbare link",
    "{email} downloaded {file}" : "{email} downloadde {file}",
    "Shared with group {group}" : "Deelde met groep {group}",
    "Removed share for group {group}" : "Share van de groep {group} verwijderd",
    "{actor} shared with group {group}" : "{actor} deelde met groep {group}",
    "{actor} removed share for group {group}" : "{actor} verwijderde de share voor groep {group}",
    "You shared {file} with group {group}" : "Je deelde {file} met groep {group}",
    "You removed group {group} from {file}" : "Je verwijderde groep  {group} van {file}",
    "{actor} shared {file} with group {group}" : "{actor} deelde {file} met groep {group}",
    "{actor} removed group {group} from {file}" : "{actor} verwijderde groep {group} van {file}",
    "Shared as public link" : "Gedeeld als een openbare link",
    "Removed public link" : "Openbare link verwijderd",
    "Public link expired" : "Openbare link is verlopen",
    "{actor} shared as public link" : "{actor} deelde als een openbare link",
    "{actor} removed public link" : "{actor} verwijderde openbare link",
    "Public link of {actor} expired" : "Openbare link van {actor} is verlopen",
    "You shared {file} as public link" : "Je deelde {file} als openbare link",
    "You removed public link for {file}" : "Je verwijderde de openbare link voor {file}",
    "Public link expired for {file}" : "Openbare link voor {file} is verlopen",
    "{actor} shared {file} as public link" : "{actor} deelde {file} als openbare link",
    "{actor} removed public link for {file}" : "{actor} verwijderde openbare link voor {file}",
    "Public link of {actor} for {file} expired" : "Openbare link van {actor} voor {file} is verlopen",
    "{user} accepted the remote share" : "{user} accepteerde externe share",
    "{user} declined the remote share" : "{user} weigerde externe share",
    "You received a new remote share {file} from {user}" : "Je ontving een nieuwe externe share voor {file} van {user}",
    "{user} accepted the remote share of {file}" : "{user} accepteerde externe share van {file}",
    "{user} declined the remote share of {file}" : "{user} weigerde de externe share van {file}",
    "{user} unshared {file} from you" : "{user} stopte met delen van {file} met jou",
    "Shared with {user}" : "Gedeeld met {user}",
    "Removed share for {user}" : "Verwijderde share voor {user}",
    "{actor} shared with {user}" : "{actor} deelde met {user}",
    "{actor} removed share for {user}" : "{actor} verwijderde de share voor {user}",
    "Shared by {actor}" : "Gedeeld door {actor}",
    "{actor} removed share" : "{actor} verwijderde de share",
    "You shared {file} with {user}" : "Je deelde {file} mey {user}",
    "You removed {user} from {file}" : "Je verwijderde {user} van {file}",
    "{actor} removed {user} from {file}" : "{actor} verwijderde {user} van {file}",
    "{actor} shared {file} with you" : "{actor} deelde {file} met jou",
    "{actor} removed you from {file}" : "{actor} verwijderde jou van {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Een bestand of map gedeeld via mail of publieke link werd <strong>gedownload</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Een bestand of map werd gedeeld vanaf <strong>een andere server</strong>",
    "A file or folder has been <strong>shared</strong>" : "Een bestand of map is <strong>gedeeld</strong>",
    "Wrong share ID, share doesn't exist" : "Onjuist deel-ID, de share bestaat niet",
    "could not delete share" : "Kon share niet verwijderen",
    "Could not delete share" : "Kon share niet verwijderen",
    "Please specify a file or folder path" : "Geef een bestand of pad van een map op",
    "Wrong path, file/folder doesn't exist" : "Onjuist pad, bestand/map bestaat niet",
    "Could not create share" : "Kon share niet aanmaken",
    "invalid permissions" : "Ongeldige rechten",
    "Please specify a valid user" : "Geef een geldige gebruiker op",
    "Group sharing is disabled by the administrator" : "Delen voor groepen is uitgeschakeld door de beheerder",
    "Please specify a valid group" : "Geef een geldige groep op",
    "Public link sharing is disabled by the administrator" : "Delen van openbare links is uitgeschakeld door de beheerder",
    "Public upload disabled by the administrator" : "Publieke upload uitgeschakeld door de systeembeheerder",
    "Public upload is only possible for publicly shared folders" : "Publieke upload is alleen mogelijk voor publiek gedeelde mappen",
    "Invalid date, date format must be YYYY-MM-DD" : "Ongeldige datum, datumnotatie moet in de vorm YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Delen van %s mislukte omdat de backend het delen van type %s niet ondersteunt",
    "Unknown share type" : "Onbekend type share",
    "Not a directory" : "Geen directory",
    "Could not lock path" : "Kon pad niet blokkeren",
    "Wrong or no update parameter given" : "Verkeerde of geen update parameter opgegeven",
    "Can't change permissions for public share links" : "Kan permissies voor openbare share links niet wijzigen",
    "Cannot increase permissions" : "Kan de rechten niet verruimen",
    "%s is publicly shared" : "%s is openbaar gedeeld",
    "Share API is disabled" : "Delen API is uitgeschakeld",
    "This share is password-protected" : "Deze share is met een wachtwoord beveiligd",
    "The password is wrong. Try again." : "Wachtwoord ongeldig. Probeer het nogmaals.",
    "Password" : "Wachtwoord",
    "No entries found in this folder" : "Niets gevonden in deze map",
    "Name" : "Naam",
    "Share time" : "Deel tijd",
    "Expiration date" : "Vervaldatm",
    "Sorry, this link doesn’t seem to work anymore." : "Sorry, deze link lijkt niet meer in gebruik te zijn.",
    "Reasons might be:" : "Redenen kunnen zijn:",
    "the item was removed" : "bestand was verwijderd",
    "the link expired" : "de link is verlopen",
    "sharing is disabled" : "delen is uitgeschakeld",
    "For more info, please ask the person who sent this link." : "Voor meer informatie, neem contact op met de persoon die u deze link heeft gestuurd.",
    "Add to your Nextcloud" : "Toevoegen aan je Nextcloud",
    "Download" : "Downloaden",
    "Download %s" : "Download %s",
    "Direct link" : "Directe link",
    "Upload files to %s" : "Upload bestanden naar %s",
    "Select or drop files" : "Selecteer of leg bestanden neer",
    "Uploading files…" : "Uploaden bestanden...",
    "Uploaded files:" : "Geüploade bestanden",
    "A public shared file or folder was <strong>downloaded</strong>" : "Een openbaar gedeeld bestand of map werd <strong>gedownloaded</strong>",
    "You received a new remote share %2$s from %1$s" : "Je ontving een nieuwe externe share %2$s van %1$s",
    "You received a new remote share from %s" : "Je ontving een nieuwe externe share van %s",
    "%1$s accepted remote share %2$s" : "%1$s accepteerde externe share %2$s",
    "%1$s declined remote share %2$s" : "%1$s weigerde externe share %2$s",
    "%1$s unshared %2$s from you" : "%1$s stopte met delen van %2$s met je",
    "Public shared folder %1$s was downloaded" : "Openbaar gedeelde map %1$s werd gedownloaded",
    "Public shared file %1$s was downloaded" : "Openbaar gedeeld bestand %1$s werd gedownloaded",
    "You shared %1$s with %2$s" : "Je deelde %1$s met %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s deelde %1$s met %3$s",
    "You removed the share of %2$s for %1$s" : "Je hebt de share van %1$s met %2$s verwijderd",
    "%2$s removed the share of %3$s for %1$s" : "%2$s heeft de share van %1$s met %3$s verwijderd",
    "You shared %1$s with group %2$s" : "Je deelde %1$s met groep %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s deelde %1$s met groep %3$s",
    "You removed the share of group %2$s for %1$s" : "Je hebt de share van %1$s met de groep %2$s verwijderd",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s heeft de share van %1$s met de groep %3$s verwijderd",
    "%2$s shared %1$s via link" : "%2$s deelde %1$s via link",
    "You shared %1$s via link" : "Je deelde %1$s via link",
    "You removed the public link for %1$s" : "Je hebt de openbare link voor %1$s verwijderd",
    "%2$s removed the public link for %1$s" : "%2$s heeft de openbare link voor %1$s verwijderd",
    "Your public link for %1$s expired" : "Je openbare link voor %1$s is verlopen",
    "The public link of %2$s for %1$s expired" : "De openbare link van %2$s voor %1$s is verlopen",
    "%2$s shared %1$s with you" : "%2$s deelde %1$s met u",
    "%2$s removed the share for %1$s" : "%2$s heeft de share van %1$s verwijderd",
    "Shared with %2$s" : "Gedeeld met %2$s",
    "Shared with %3$s by %2$s" : "Gedeeld met %3$s door %2$s",
    "Removed share for %2$s" : "Share van %2$s verwijderd",
    "%2$s removed share for %3$s" : "%2$s verwijderde de share van %3$s",
    "Shared with group %2$s" : "Gedeeld met groep %2$s",
    "Shared with group %3$s by %2$s" : "Gedeeld met groep %3$s door %2$s",
    "Removed share of group %2$s" : "Share van de groep %2$s verwijderd",
    "%2$s removed share of group %3$s" : "%2$s verwijderde share met groep %3$s",
    "Shared via link by %2$s" : "Gedeeld via link door %2$s",
    "Shared via public link" : "Gedeeld via een openbare link",
    "%2$s removed public link" : "%2$s verwijderede openbare link",
    "Public link of %2$s expired" : "Openbare link van %2$s is verlopen",
    "Shared by %2$s" : "Gedeeld door %2$s",
    "Shares" : "Gedeeld"
},
"nplurals=2; plural=(n != 1);");
